<?php

namespace Litecms\Busquery\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Busquery\Models\Busqueries;

class BusqueriesPolicy
{

    /**
     * Determine if the given user can view the busqueries.
     *
     * @param UserPolicy $user
     * @param Busqueries $busqueries
     *
     * @return bool
     */
    public function view(UserPolicy $user, Busqueries $busqueries)
    {
        if ($user->canDo('busquery.busqueries.view') && $user->isAdmin()) {
            return true;
        }

        return $busqueries->user_id == user_id() && $busqueries->user_type == user_type();
    }

    /**
     * Determine if the given user can create a busqueries.
     *
     * @param UserPolicy $user
     * @param Busqueries $busqueries
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('busquery.busqueries.create');
    }

    /**
     * Determine if the given user can update the given busqueries.
     *
     * @param UserPolicy $user
     * @param Busqueries $busqueries
     *
     * @return bool
     */
    public function update(UserPolicy $user, Busqueries $busqueries)
    {
        if ($user->canDo('busquery.busqueries.edit') && $user->isAdmin()) {
            return true;
        }

        return $busqueries->user_id == user_id() && $busqueries->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given busqueries.
     *
     * @param UserPolicy $user
     * @param Busqueries $busqueries
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Busqueries $busqueries)
    {
        return $busqueries->user_id == user_id() && $busqueries->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given busqueries.
     *
     * @param UserPolicy $user
     * @param Busqueries $busqueries
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Busqueries $busqueries)
    {
        if ($user->canDo('busquery.busqueries.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given busqueries.
     *
     * @param UserPolicy $user
     * @param Busqueries $busqueries
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Busqueries $busqueries)
    {
        if ($user->canDo('busquery.busqueries.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
